var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
define(["require", "exports", "./workerManager", "monaco-editor/esm/vs/basic-languages/graphql/graphql", "./languageFeatures"], function (require, exports, workerManager_1, graphql_1, languageFeatures) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.richLanguageConfig = exports.setupMode = void 0;
    languageFeatures = __importStar(languageFeatures);
    function setupMode(defaults) {
        const disposables = [];
        const providers = [];
        const client = new workerManager_1.WorkerManager(defaults);
        const { languageId } = defaults;
        disposables.push(client);
        const worker = (...uris) => {
            try {
                return client.getLanguageServiceWorker(...uris);
            }
            catch (err) {
                throw Error('Error fetching graphql language service worker');
            }
        };
        defaults.setWorker(worker);
        monaco.languages.setLanguageConfiguration(languageId, exports.richLanguageConfig);
        monaco.languages.setMonarchTokensProvider(languageId, graphql_1.language);
        function registerFormattingProvider() {
            const { modeConfiguration } = defaults;
            if (modeConfiguration.documentFormattingEdits) {
                providers.push(monaco.languages.registerDocumentFormattingEditProvider(defaults.languageId, new languageFeatures.DocumentFormattingAdapter(worker)));
            }
        }
        function registerProviders() {
            const { modeConfiguration } = defaults;
            disposeAll(providers);
            if (modeConfiguration.completionItems) {
                providers.push(monaco.languages.registerCompletionItemProvider(defaults.languageId, new languageFeatures.CompletionAdapter(worker)));
            }
            if (modeConfiguration.diagnostics) {
                providers.push(new languageFeatures.DiagnosticsAdapter(defaults, worker));
            }
            if (modeConfiguration.hovers) {
                providers.push(monaco.languages.registerHoverProvider(defaults.languageId, new languageFeatures.HoverAdapter(worker)));
            }
            registerFormattingProvider();
        }
        registerProviders();
        let { modeConfiguration, schemaConfig, formattingOptions } = defaults;
        defaults.onDidChange(newDefaults => {
            if (defaults.schemaString !== newDefaults.schemaString) {
                registerProviders();
            }
            if (newDefaults.modeConfiguration !== modeConfiguration) {
                modeConfiguration = newDefaults.modeConfiguration;
                registerProviders();
            }
            if (newDefaults.schemaConfig !== schemaConfig) {
                schemaConfig = newDefaults.schemaConfig;
                registerProviders();
            }
            if (newDefaults.formattingOptions !== formattingOptions) {
                formattingOptions = newDefaults.formattingOptions;
                registerFormattingProvider();
            }
        });
        disposables.push(asDisposable(providers));
        return asDisposable(disposables);
    }
    exports.setupMode = setupMode;
    function asDisposable(disposables) {
        return { dispose: () => disposeAll(disposables) };
    }
    function disposeAll(disposables) {
        var _a;
        while (disposables.length) {
            (_a = disposables.pop()) === null || _a === void 0 ? void 0 : _a.dispose();
        }
    }
    exports.richLanguageConfig = {
        comments: {
            lineComment: '#',
        },
        brackets: [
            ['{', '}'],
            ['[', ']'],
            ['(', ')'],
        ],
        autoClosingPairs: [
            { open: '{', close: '}' },
            { open: '[', close: ']' },
            { open: '(', close: ')' },
            { open: '"""', close: '"""', notIn: ['string', 'comment'] },
            { open: '"', close: '"', notIn: ['string', 'comment'] },
        ],
        surroundingPairs: [
            { open: '{', close: '}' },
            { open: '[', close: ']' },
            { open: '(', close: ')' },
            { open: '"""', close: '"""' },
            { open: '"', close: '"' },
        ],
        folding: {
            offSide: true,
        },
    };
});
//# sourceMappingURL=graphqlMode.js.map